@@ -23,7 +23,6 @@
 #endif
 
 #include <glib.h>
-#include <glib-object.h>
 #include <glib/gi18n.h>
 
 #include <gdk-pixbuf/gdk-pixbuf.h>
@@ -41,11 +40,6 @@ static void   cover_thumbnailer_provider_finalize                  (GObject
 
 
 
-struct _CoverThumbnailerProviderClass
-{
-  GObjectClass __parent__;
-};
-
 struct _CoverThumbnailerProvider
 {
   GObject __parent__;
@@ -144,7 +138,7 @@ cover_thumbnailer_provider_get_thumbnailers (TumblerThumbnailerProvider *provide
   uri_schemes = tumbler_util_get_supported_uri_schemes ();
 
   /* create the pixbuf thumbnailer */
-  thumbnailer = g_object_new (TYPE_COVER_THUMBNAILER,
+  thumbnailer = g_object_new (COVER_TYPE_THUMBNAILER,
                               "uri-schemes", uri_schemes,
                               "mime-types", mime_types,
                               NULL);
