@@ -151,7 +151,7 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (tumbler_util_guess_is_sparse (info))
   {
     g_debug ("Video file '%s' is probably sparse, skipping", uri);
-    g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
+    g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
                            TUMBLER_ERROR_NO_CONTENT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
     return;
@@ -180,7 +180,7 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (path == NULL)
     {
       /* there was an error, emit error signal */
-      g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
+      g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
                              TUMBLER_ERROR_INVALID_FORMAT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
       /* clean up */
@@ -196,7 +196,7 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (res != 0)
     {
       /* there was an error, emit error signal */
-      g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
+      g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
                              TUMBLER_ERROR_INVALID_FORMAT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
       /* clean up */
@@ -213,7 +213,7 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (v_stream == NULL)
     {
       /* there was an error, emit error signal */
-      g_signal_emit_by_name (thumbnailer, "error", uri, TUMBLER_ERROR,
+      g_signal_emit_by_name (thumbnailer, "error", info, TUMBLER_ERROR,
                              TUMBLER_ERROR_INVALID_FORMAT, TUMBLER_ERROR_MESSAGE_CREATION_FAILED);
 
       /* clean up */
@@ -230,7 +230,7 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (v_pixbuf == NULL)
     {
       /* emit an error signal */
-      g_signal_emit_by_name (thumbnailer, "error", uri,
+      g_signal_emit_by_name (thumbnailer, "error", info,
                              error->domain, error->code, error->message);
       g_error_free (error);
 
@@ -263,14 +263,14 @@ ffmpeg_thumbnailer_create (TumblerAbstractThumbnailer *thumbnailer,
   if (error != NULL)
     {
       /* emit an error signal */
-      g_signal_emit_by_name (thumbnailer, "error", uri,
+      g_signal_emit_by_name (thumbnailer, "error", info,
                              error->domain, error->code, error->message);
       g_error_free (error);
     }
   else
     {
       /* otherwise, the thumbnail is now ready */
-      g_signal_emit_by_name (thumbnailer, "ready", uri);
+      g_signal_emit_by_name (thumbnailer, "ready", info);
     }
 
   /* clean up */
