@@ -24,7 +24,6 @@
 #endif
 
 #include <glib.h>
-#include <glib-object.h>
 
 #include <tumbler/tumbler.h>
 
@@ -38,11 +37,6 @@ static GList *gepub_thumbnailer_provider_get_thumbnailers          (TumblerThumb
 
 
 
-struct _GepubThumbnailerProviderClass
-{
-  GObjectClass __parent__;
-};
-
 struct _GepubThumbnailerProvider
 {
   GObject __parent__;
@@ -113,7 +107,7 @@ gepub_thumbnailer_provider_get_thumbnailers (TumblerThumbnailerProvider *provide
   uri_schemes = tumbler_util_get_supported_uri_schemes ();
 
   /* create the pixbuf thumbnailer */
-  thumbnailer = g_object_new (TYPE_GEPUB_THUMBNAILER, 
+  thumbnailer = g_object_new (GEPUB_TYPE_THUMBNAILER,
                               "uri-schemes", uri_schemes,
                               "mime-types", mime_types, 
                               NULL);
