@@ -65,7 +65,7 @@ tumbler_plugin_initialize (TumblerProviderPlugin *plugin)
   pixbuf_thumbnailer_provider_register (plugin);
 
   /* set up the plugin provider type list */
-  type_list[0] = TYPE_PIXBUF_THUMBNAILER_PROVIDER;
+  type_list[0] = PIXBUF_TYPE_THUMBNAILER_PROVIDER;
 }
 
 
