@@ -21,22 +21,14 @@
 #ifndef __PIXBUF_THUMBNAILER_H__
 #define __PIXBUF_THUMBNAILER_H__
 
-#include <glib-object.h>
+#include <tumbler/tumbler.h>
 
 G_BEGIN_DECLS;
 
-#define TYPE_PIXBUF_THUMBNAILER            (pixbuf_thumbnailer_get_type ())
-#define PIXBUF_THUMBNAILER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_PIXBUF_THUMBNAILER, PixbufThumbnailer))
-#define PIXBUF_THUMBNAILER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_PIXBUF_THUMBNAILER, PixbufThumbnailerClass))
-#define IS_PIXBUF_THUMBNAILER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_PIXBUF_THUMBNAILER))
-#define IS_PIXBUF_THUMBNAILER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_PIXBUF_THUMBNAILER)
-#define PIXBUF_THUMBNAILER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_PIXBUF_THUMBNAILER, PixbufThumbnailerClass))
+#define PIXBUF_TYPE_THUMBNAILER (pixbuf_thumbnailer_get_type ())
+G_DECLARE_FINAL_TYPE (PixbufThumbnailer, pixbuf_thumbnailer, PIXBUF, THUMBNAILER, TumblerAbstractThumbnailer)
 
-typedef struct _PixbufThumbnailerClass   PixbufThumbnailerClass;
-typedef struct _PixbufThumbnailer        PixbufThumbnailer;
-
-GType pixbuf_thumbnailer_get_type (void) G_GNUC_CONST;
-void  pixbuf_thumbnailer_register (TumblerProviderPlugin *plugin);
+void pixbuf_thumbnailer_register (TumblerProviderPlugin *plugin);
 
 G_END_DECLS;
 
