@@ -65,7 +65,7 @@ tumbler_plugin_initialize (TumblerProviderPlugin *plugin)
   poppler_thumbnailer_provider_register (plugin);
 
   /* set up the plugin provider type list */
-  type_list[0] = TYPE_POPPLER_THUMBNAILER_PROVIDER;
+  type_list[0] = POPPLER_TYPE_THUMBNAILER_PROVIDER;
 }
 
 
