@@ -23,8 +23,6 @@
 #endif
 
 #include <glib.h>
-#include <glib-object.h>
-
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <tumbler/tumbler.h>
@@ -39,11 +37,6 @@ static GList *poppler_thumbnailer_provider_get_thumbnailers          (TumblerThu
 
 
 
-struct _PopplerThumbnailerProviderClass
-{
-  GObjectClass __parent__;
-};
-
 struct _PopplerThumbnailerProvider
 {
   GObject __parent__;
@@ -114,7 +107,7 @@ poppler_thumbnailer_provider_get_thumbnailers (TumblerThumbnailerProvider *provi
   uri_schemes = tumbler_util_get_supported_uri_schemes ();
 
   /* create the pixbuf thumbnailer */
-  thumbnailer = g_object_new (TYPE_POPPLER_THUMBNAILER, 
+  thumbnailer = g_object_new (POPPLER_TYPE_THUMBNAILER,
                               "uri-schemes", uri_schemes, "mime-types", mime_types, 
                               NULL);
 
