@@ -25,18 +25,10 @@
 
 G_BEGIN_DECLS
 
-#define TYPE_RAW_THUMBNAILER_PROVIDER            (raw_thumbnailer_provider_get_type ())
-#define RAW_THUMBNAILER_PROVIDER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RAW_THUMBNAILER_PROVIDER, RawThumbnailerProvider))
-#define RAW_THUMBNAILER_PROVIDER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_RAW_THUMBNAILER_PROVIDER, RawThumbnailerProviderClass))
-#define IS_RAW_THUMBNAILER_PROVIDER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RAW_THUMBNAILER_PROVIDER))
-#define IS_RAW_THUMBNAILER_PROVIDER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_RAW_THUMBNAILER_PROVIDER)
-#define RAW_THUMBNAILER_PROVIDER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_RAW_THUMBNAILER_PROVIDER, RawThumbnailerProviderClass))
+#define RAW_TYPE_THUMBNAILER_PROVIDER (raw_thumbnailer_provider_get_type ())
+G_DECLARE_FINAL_TYPE (RawThumbnailerProvider, raw_thumbnailer_provider, RAW, THUMBNAILER_PROVIDER, GObject)
 
-typedef struct _RawThumbnailerProviderClass RawThumbnailerProviderClass;
-typedef struct _RawThumbnailerProvider      RawThumbnailerProvider;
-
-GType raw_thumbnailer_provider_get_type (void) G_GNUC_CONST;
-void  raw_thumbnailer_provider_register (TumblerProviderPlugin *plugin);
+void raw_thumbnailer_provider_register (TumblerProviderPlugin *plugin);
 
 G_END_DECLS
 
