@@ -22,24 +22,14 @@
 #ifndef __RAW_THUMBNAILER_H__
 #define __RAW_THUMBNAILER_H__
 
-#include <glib-object.h>
+#include <tumbler/tumbler.h>
 
 G_BEGIN_DECLS
 
-#define TYPE_RAW_THUMBNAILER            (raw_thumbnailer_get_type ())
-#define RAW_THUMBNAILER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TYPE_RAW_THUMBNAILER, RawThumbnailer))
-#define RAW_THUMBNAILER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TYPE_RAW_THUMBNAILER, RawThumbnailerClass))
-#define IS_RAW_THUMBNAILER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TYPE_RAW_THUMBNAILER))
-#define IS_RAW_THUMBNAILER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TYPE_RAW_THUMBNAILER)
-#define RAW_THUMBNAILER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), TYPE_RAW_THUMBNAILER, RawThumbnailerClass))
+#define RAW_TYPE_THUMBNAILER (raw_thumbnailer_get_type ())
+G_DECLARE_FINAL_TYPE (RawThumbnailer, raw_thumbnailer, RAW, THUMBNAILER, TumblerAbstractThumbnailer)
 
-
-
-typedef struct _RawThumbnailerClass   RawThumbnailerClass;
-typedef struct _RawThumbnailer        RawThumbnailer;
-
-GType raw_thumbnailer_get_type (void) G_GNUC_CONST;
-void  raw_thumbnailer_register (TumblerProviderPlugin *plugin);
+void raw_thumbnailer_register (TumblerProviderPlugin *plugin);
 
 G_END_DECLS
 
