@@ -30,9 +30,6 @@
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
 #include <glib/gprintf.h>
-#include <glib-object.h>
-#include <gio/gio.h>
-
 #include <gdk-pixbuf/gdk-pixbuf.h>
 
 #include <png.h>
@@ -66,11 +63,6 @@ static GList            *xdg_cache_cache_get_flavors        (TumblerCache
 
 
 
-struct _XDGCacheCacheClass
-{
-  GObjectClass __parent__;
-};
-
 struct _XDGCacheCache
 {
   GObject __parent__;
