@@ -27,7 +27,6 @@
 #endif
 
 #include <glib.h>
-#include <glib-object.h>
 
 #include <tumbler/tumbler-provider-factory.h>
 #include <tumbler/tumbler-provider-plugin.h>
@@ -44,11 +43,6 @@ static GList *tumbler_provider_factory_load_plugins (TumblerProviderFactory
 
 
 
-struct _TumblerProviderFactoryClass
-{
-  GObjectClass __parent__;
-};
-
 struct _TumblerProviderFactory
 {
   GObject __parent__;
