@@ -24,7 +24,6 @@
 
 #include <glib.h>
 #include <glib/gi18n.h>
-#include <glib-object.h>
 #include <gmodule.h>
 
 #include "tumbler/tumbler-provider-plugin.h"
@@ -46,11 +45,6 @@ static void     tumbler_provider_plugin_unload       (GTypeModule
 
 
 
-struct _TumblerProviderPluginClass
-{
-  GTypeModuleClass __parent__;
-};
-
 struct _TumblerProviderPlugin
 {
   GTypeModule __parent__;
@@ -188,7 +182,7 @@ tumbler_provider_plugin_get_types (const TumblerProviderPlugin *plugin,
                                    const GType                **types,
                                    gint                        *n_types)
 {
-  g_return_if_fail (TUMBLER_IS_PROVIDER_PLUGIN (plugin));
+  g_return_if_fail (TUMBLER_IS_PROVIDER_PLUGIN ((TumblerProviderPlugin *) plugin));
   g_return_if_fail (plugin->get_types != NULL);
   g_return_if_fail (types != NULL);
   g_return_if_fail (n_types != NULL);
