@@ -22,22 +22,14 @@
 #ifndef __TUMBLER_MANAGER_H__
 #define __TUMBLER_MANAGER_H__
 
+#include <tumblerd/tumbler-component.h>
 #include <tumblerd/tumbler-lifecycle-manager.h>
 #include <tumblerd/tumbler-registry.h>
 
 G_BEGIN_DECLS;
 
-#define TUMBLER_TYPE_MANAGER            (tumbler_manager_get_type ())
-#define TUMBLER_MANAGER(obj)            (G_TYPE_CHECK_INSTANCE_CAST ((obj), TUMBLER_TYPE_MANAGER, TumblerManager))
-#define TUMBLER_MANAGER_CLASS(klass)    (G_TYPE_CHECK_CLASS_CAST ((klass), TUMBLER_TYPE_MANAGER, TumblerManagerClass))
-#define TUMBLER_IS_MANAGER(obj)         (G_TYPE_CHECK_INSTANCE_TYPE ((obj), TUMBLER_TYPE_MANAGER))
-#define TUMBLER_IS_MANAGER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), TUMBLER_TYPE_MANAGER)
-#define TUMBLER_MANAGER_GET_CLASS(obj)  (G_TYPE_INSTANCE_GET_CLASS ((obj), TUMBLER_TYPE_MANAGER, TumblerManagerClass))
-
-typedef struct _TumblerManagerClass TumblerManagerClass;
-typedef struct _TumblerManager      TumblerManager;
-
-GType           tumbler_manager_get_type      (void) G_GNUC_CONST;
+#define TUMBLER_TYPE_MANAGER (tumbler_manager_get_type ())
+G_DECLARE_FINAL_TYPE (TumblerManager, tumbler_manager, TUMBLER, MANAGER, TumblerComponent)
 
 TumblerManager *tumbler_manager_new           (GDBusConnection         *connection,
                                                TumblerLifecycleManager *lifecycle_manager,
